@@ -131,7 +131,7 @@ ExampleWindow::ExampleWindow() :
   m_ListBox.signal_row_activated().connect(sigc::mem_fun(*this, &ExampleWindow::on_row_activated));
 
   // Add some rows to the ListBox.
-  ExampleRow* row = Gtk::manage(new ExampleRow("blah4", 4));
+  auto row = Gtk::manage(new ExampleRow("blah4", 4));
   m_ListBox.append(*row);
   m_ListBox.append(m_Row3); // blah3
   row = Gtk::manage(new ExampleRow("blah1", 1));
@@ -209,21 +209,21 @@ void ExampleWindow::on_sort_clicked()
 
 void ExampleWindow::on_reverse_sort_clicked()
 {
-  m_ListBox.set_sort_func(sigc::ptr_fun(&ExampleWindow::reverse_sort_func));
+  m_ListBox.set_sort_func(
+    [](Gtk::ListBoxRow* row1, Gtk::ListBoxRow* row2)
+    {
+      return sort_func(row2, row1);
+    });
 }
 
 int ExampleWindow::sort_func(Gtk::ListBoxRow* row1, Gtk::ListBoxRow* row2)
 {
-  ExampleRow* xrow1 = dynamic_cast<ExampleRow*>(row1);
-  ExampleRow* xrow2 = dynamic_cast<ExampleRow*>(row2);
+  const auto xrow1 = dynamic_cast<ExampleRow*>(row1);
+  const auto xrow2 = dynamic_cast<ExampleRow*>(row2);
   if (xrow1 && xrow2)
     return xrow1->get_sort_id() - xrow2->get_sort_id();
-  return 0;
-}
 
-int ExampleWindow::reverse_sort_func(Gtk::ListBoxRow* row1, Gtk::ListBoxRow* row2)
-{
-  return sort_func(row2, row1);
+  return 0;
 }
 
 void ExampleWindow::on_change_clicked()
@@ -242,7 +242,12 @@ void ExampleWindow::on_change_clicked()
 
 void ExampleWindow::on_filter_clicked()
 {
-  m_ListBox.set_filter_func(sigc::ptr_fun(&ExampleWindow::filter_func));
+  m_ListBox.set_filter_func(
+   [] (Gtk::ListBoxRow* row)
+   {
+     auto xrow = dynamic_cast<ExampleRow*>(row);
+     return xrow && xrow->get_text() != "blah3";
+   });
 }
 
 void ExampleWindow::on_unfilter_clicked()
@@ -250,17 +255,11 @@ void ExampleWindow::on_unfilter_clicked()
   m_ListBox.unset_filter_func();
 }
 
-bool ExampleWindow::filter_func(Gtk::ListBoxRow* row)
-{
-  ExampleRow* xrow = dynamic_cast<ExampleRow*>(row);
-  return xrow && xrow->get_text() != "blah3";
-}
-
 void ExampleWindow::on_add_clicked()
 {
   static int new_button_nr = 1;
   const Glib::ustring text = "blah2 new " + Glib::ustring::format(new_button_nr);
-  ExampleRow* new_row = Gtk::manage(new ExampleRow(text, new_button_nr));
+  auto new_row = Gtk::manage(new ExampleRow(text, new_button_nr));
   new_row->show_all();
   m_ListBox.append(*new_row);
   ++new_button_nr;
@@ -278,27 +277,28 @@ void ExampleWindow::on_unseparate_clicked()
 
 void ExampleWindow::update_header_func(Gtk::ListBoxRow* row, Gtk::ListBoxRow* before)
 {
-  ExampleRow* xrow = dynamic_cast<ExampleRow*>(row);
+  auto xrow = dynamic_cast<ExampleRow*>(row);
   if (!before || (xrow && xrow->get_text() == "blah3"))
   {
     // Create header if needed.
     if (!row->get_header())
     {
-      Gtk::Box* hbox = Gtk::manage(new Gtk::Box(Gtk::ORIENTATION_HORIZONTAL));
-      Gtk::Label* label = Gtk::manage(new Gtk::Label("Header"));
+      auto hbox = Gtk::manage(new Gtk::Box(Gtk::ORIENTATION_HORIZONTAL));
+      auto label = Gtk::manage(new Gtk::Label("Header"));
       hbox->pack_start(*label, Gtk::PACK_SHRINK);
-      Gtk::Button* button = Gtk::manage(new Gtk::Button("button"));
+      auto button = Gtk::manage(new Gtk::Button("button"));
       hbox->pack_start(*button, Gtk::PACK_SHRINK);
       hbox->show_all();
       row->set_header(*hbox);
     }
-    Gtk::Container* header = dynamic_cast<Gtk::Container*>(row->get_header());
+
+    auto header = dynamic_cast<Gtk::Container*>(row->get_header());
     if (header)
     {
       std::vector<Gtk::Widget*> children = header->get_children();
       if (children.size() > 0)
       {
-        Gtk::Label* label = dynamic_cast<Gtk::Label*>(children[0]);
+        auto label = dynamic_cast<Gtk::Label*>(children[0]);
         if (label && xrow)
           label->set_text("Header " + Glib::ustring::format(xrow->get_sort_id()));
       }
